.. _omics_examples:

=========================
Omics Biomarker Examples
=========================

Plots results of running omics based biomarker models functions. Includes methylation and transcriptomic data.
